Coverage for pages.urls

# Coverage for pages.urls : 89%

## 9 statements 8 run 0 excluded 1 missing

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 | from django.conf.urls.defaults import url, include, patterns from django.conf.urls.defaults import handler404, handler500 from pages.views import details from pages import settings urlpatterns = patterns('', # Public pages url(r'^$', details, name='pages-root'), ) if settings.PAGE_USE_LANGUAGE_PREFIX: urlpatterns += patterns('', url(r'^(?P<lang>[-\w]+)/(?P<path>.*)$', details, name='pages-details-by-path') ) else: urlpatterns += patterns('', url(r'^(?P<path>.*)$', details, name='pages-details-by-path') )